summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMarin Jankovski <marin@gitlab.com>2014-03-17 10:41:39 +0100
committerMarin Jankovski <marin@gitlab.com>2014-03-17 13:05:20 +0100
commit55e2f353d412537a58ff19a63a8cc3d5651d881f (patch)
tree38d485172105eed1c6d1dc602f310642ca71f216
parent36c094b08dc37887050eedad7f0fb4f05e79f9cc (diff)
downloadgitlab-ce-55e2f353d412537a58ff19a63a8cc3d5651d881f.tar.gz
Link to blob instead of linking to wiki.
-rw-r--r--app/helpers/gitlab_markdown_helper.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/app/helpers/gitlab_markdown_helper.rb b/app/helpers/gitlab_markdown_helper.rb
index 7f72ab54838..685ef752d84 100644
--- a/app/helpers/gitlab_markdown_helper.rb
+++ b/app/helpers/gitlab_markdown_helper.rb
@@ -134,12 +134,12 @@ module GitlabMarkdownHelper
end
# Checks if the path exists in the repo
# eg. checks if doc/README.md exists, if it doesn't then it is a wiki link
def path_with_ref(path, ref)
if file_exists?(path)
"#{local_path(path)}/#{correct_ref(ref)}"
else
- "wikis"
+ "blob/#{correct_ref(ref)}"
end
end
@@ -134,12 +134,12 @@ module GitlabMarkdownHelper
end
# Checks if the path exists in the repo
- # eg. checks if doc/README.md exists, if it doesn't then it is a wiki link
+ # eg. checks if doc/README.md exists, if not then link to blob
def path_with_ref(path, ref)
if file_exists?(path)